==> forms_to_email-8.x-1.1.tar.gz: forms_to_email/src/Form/FormsToEmailConfigurationForm.php <==
<?php

namespace Drupal\forms_to_email\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class SettingsForm.
 *
 * @package Drupal\forms_to_email\Form
 *
 * @ingroup forms_to_email
 */
class FormsToEmailConfigurationForm extends ConfigFormBase {

  /**
   * Gets the configuration names that will be editable.
   *
   * @return array
   *   An array of configuration object names that are editable if called in
   *   conjunction with the trait's config() method.
   */
  protected function getEditableConfigNames() {
    return [
      'forms_to_email.settings',
    ];
  }

  /**
   * Returns a unique string identifying the form.
   *
   * @return string
   *   The unique string identifying the form.
   */
  public function getFormId() {
    return 'forms_to_email_general';
  }

  /**
   * Defines the settings form for Forms to Email.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   *
   * @return array
   *   Form definition array.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $config = $this->config('forms_to_email.settings');

    $form['forms_to_email_general'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('General settings'),
    ];

    $form['forms_to_email_general']['forms_to_email_form_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Form ID'),
      '#default_value' => $config->get('forms_to_email_form_id'),
      '#description' => $this->t('Form to be alter'),
      '#required' => TRUE,
    ];

    $form['forms_to_email_general']['forms_to_email_from'] = [
      '#type' => 'textfield',
      '#title' => $this->t('From'),
      '#default_value' => $config->get('forms_to_email_from'),
      '#required' => TRUE,
    ];

    $form['forms_to_email_general']['forms_to_email_to'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Email to'),
      '#default_value' => $config->get('forms_to_email_to'),
      '#required' => FALSE,
    ];

    $form['forms_to_email_general']['forms_to_email_subject'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Subject'),
      '#default_value' => $config->get('forms_to_email_subject'),
      '#required' => TRUE,
    ];

    $form['forms_to_email_general']['forms_to_email_default_redirect_success'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Redirect in success'),
      '#default_value' => $config->get('forms_to_email_default_redirect_success'),
      '#required' => FALSE,
      '#description' => $this->t('Redirect for success. Use one per line with key|value format. E.g. form_id|thank-you'),
    ];

    $disable_other_submits = 'yes';

    if (!empty($config->get('forms_to_email_disable_other_submits'))) {
      $disable_other_submits = $config->get('forms_to_email_disable_other_submits');
    }

    $form['forms_to_email_general']['forms_to_email_disable_other_submits'] = [
      '#type' => 'select',
      '#title' => $this->t('Disable other submits'),
      '#options' => [
        'yes' => $this->t('Yes'),
        'no' => $this->t('No'),
      ],
      '#default_value' => $disable_other_submits,
    ];

    $form['forms_to_email_general']['forms_to_email_fields_to_ignore'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Fields to Ignore'),
      '#default_value' => $config->get('forms_to_email_fields_to_ignore'),
      '#required' => FALSE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $this->configFactory->getEditable('forms_to_email.settings')
      // Set the submitted configuration setting.
      ->set('forms_to_email_form_id', $form_state->getValue('forms_to_email_form_id'))
      ->set('forms_to_email_from', $form_state->getValue('forms_to_email_from'))
      ->set('forms_to_email_to', $form_state->getValue('forms_to_email_to'))
      ->set('forms_to_email_subject', $form_state->getValue('forms_to_email_subject'))
      ->set('forms_to_email_default_redirect_success', $form_state->getValue('forms_to_email_default_redirect_success'))
      ->set('forms_to_email_disable_other_submits', $form_state->getValue('forms_to_email_disable_other_submits'))
      ->set('forms_to_email_fields_to_ignore', $form_state->getValue('forms_to_email_fields_to_ignore'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}

==> forms_to_email-8.x-1.2.tar.gz: forms_to_email/src/Form/FormsToEmailConfigurationForm.php <==
<?php

namespace Drupal\forms_to_email\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class SettingsForm.
 *
 * @package Drupal\forms_to_email\Form
 *
 * @ingroup forms_to_email
 */
class FormsToEmailConfigurationForm extends ConfigFormBase {

  /**
   * Gets the configuration names that will be editable.
   *
   * @return array
   *   An array of configuration object names that are editable if called in
   *   conjunction with the trait's config() method.
   */
  protected function getEditableConfigNames() {
    return [
      'forms_to_email.settings',
    ];
  }

  /**
   * Returns a unique string identifying the form.
   *
   * @return string
   *   The unique string identifying the form.
   */
  public function getFormId() {
    return 'forms_to_email_general';
  }

  /**
   * Defines the settings form for Forms to Email.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   *
   * @return array
   *   Form definition array.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $config = $this->config('forms_to_email.settings');

    $form['forms_to_email_general'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('General settings'),
    ];

    $form['forms_to_email_general']['forms_to_email_form_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Form ID'),
      '#default_value' => $config->get('forms_to_email_form_id'),
      '#description' => $this->t('Form to be alter'),
      '#required' => TRUE,
    ];

    $form['forms_to_email_mail_settings'] = [
      '#type' => 'details',
      '#title' => $this->t('Email settings'),
      '#open'  => FALSE,
    ];

    $form['forms_to_email_mail_settings']['forms_to_email_from'] = [
      '#type' => 'textfield',
      '#title' => $this->t('From'),
      '#default_value' => $config->get('forms_to_email_from'),
      '#required' => TRUE,
    ];

    $form['forms_to_email_mail_settings']['forms_to_email_to'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Email to'),
      '#default_value' => $config->get('forms_to_email_to'),
      '#required' => FALSE,
    ];

    $form['forms_to_email_mail_settings']['forms_to_email_subject'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Subject'),
      '#default_value' => $config->get('forms_to_email_subject'),
      '#required' => TRUE,
    ];

    $form['forms_to_email_advanced'] = [
      '#type' => 'details',
      '#title' => $this->t('Advanced'),
      '#open'  => FALSE,
    ];

    $form['forms_to_email_advanced']['forms_to_email_default_redirect_success'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Redirect in success'),
      '#default_value' => $config->get('forms_to_email_default_redirect_success'),
      '#required' => FALSE,
      '#description' => $this->t('Redirect for success. Use one per line with key|value format. E.g. form_id|thank-you'),
    ];

    $disable_other_submits = 'yes';

    if (!empty($config->get('forms_to_email_disable_other_submits'))) {
      $disable_other_submits = $config->get('forms_to_email_disable_other_submits');
    }

    $form['forms_to_email_advanced']['forms_to_email_disable_other_submits'] = [
      '#type' => 'select',
      '#title' => $this->t('Disable other submits'),
      '#options' => [
        'yes' => $this->t('Yes'),
        'no' => $this->t('No'),
      ],
      '#default_value' => $disable_other_submits,
    ];

    $form['forms_to_email_advanced']['forms_to_email_fields_to_ignore'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Fields to Ignore'),
      '#default_value' => $config->get('forms_to_email_fields_to_ignore'),
      '#required' => FALSE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $this->configFactory->getEditable('forms_to_email.settings')
      // Set the submitted configuration setting.
      ->set('forms_to_email_form_id', $form_state->getValue('forms_to_email_form_id'))
      ->set('forms_to_email_from', $form_state->getValue('forms_to_email_from'))
      ->set('forms_to_email_to', $form_state->getValue('forms_to_email_to'))
      ->set('forms_to_email_subject', $form_state->getValue('forms_to_email_subject'))
      ->set('forms_to_email_default_redirect_success', $form_state->getValue('forms_to_email_default_redirect_success'))
      ->set('forms_to_email_disable_other_submits', $form_state->getValue('forms_to_email_disable_other_submits'))
      ->set('forms_to_email_fields_to_ignore', $form_state->getValue('forms_to_email_fields_to_ignore'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
